@@ -210,6 +210,11 @@ class Pets(BaseModel):
 class Pets(BaseModel):
     __root__: List[Pet]''',
         ),
+        (
+            {'type': 'array', 'items': {},},
+            '''class Pets(BaseModel):
+    __root__: List''',
+        ),
     ],
 )
 def test_parse_array(source_obj, generated_classes):
@@ -840,6 +845,36 @@ class Error(BaseModel):
     )
 
 
+def test_openapi_parser_parse_nested_anyof():
+    parser = OpenAPIParser(
+        BaseModel,
+        CustomRootType,
+        data_model_field_type=DataModelField,
+        text=Path(DATA_PATH / 'nested_anyof.yaml').read_text(),
+    )
+    assert (
+        parser.parse()
+        == '''from __future__ import annotations
+
+from typing import List, Optional, Union
+
+from pydantic import BaseModel
+
+
+class Type1(BaseModel):
+    prop: Optional[str] = None
+
+
+class Type2(BaseModel):
+    prop: Optional[str] = None
+
+
+class Container(BaseModel):
+    contents: List[Union[Type1, Type2]]
+'''
+    )
+
+
 def test_openapi_parser_parse_allof():
     parser = OpenAPIParser(
         BaseModel, CustomRootType, text=Path(DATA_PATH / 'allof.yaml').read_text()
@@ -1524,3 +1559,44 @@ def test_openapi_parser_parse_additional_properties(
         base_class=base_class,
     )
     assert parser.parse(with_import=with_import, format_=format_) == result
+
+
+@pytest.mark.parametrize(
+    'with_import, format_, base_class, result',
+    [
+        (
+            True,
+            True,
+            None,
+            '''from __future__ import annotations
+
+from enum import Enum
+from typing import List
+
+from pydantic import BaseModel
+
+
+class Type1Enum(Enum):
+    enumOne = 'enumOne'
+    enumTwo = 'enumTwo'
+
+
+class Type1(BaseModel):
+    __root__: List[Type1Enum]
+
+
+class Type2(Enum):
+    enumFour = 'enumFour'
+    enumFive = 'enumFive'
+''',
+        ),
+    ],
+)
+def test_openapi_parser_parse_array_enum(with_import, format_, base_class, result):
+    parser = OpenAPIParser(
+        BaseModel,
+        CustomRootType,
+        text=Path(DATA_PATH / 'array_enum.yaml').read_text(),
+        base_class=base_class,
+    )
+    assert parser.parse(with_import=with_import, format_=format_) == result
